==> chaosmesh-model-5.2.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/DNSChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface DNSChaosListFluent<A extends DNSChaosListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,DNSChaos item);
    public A setToItems(int index,DNSChaos item);
    public A addToItems(DNSChaos... items);
    public A addAllToItems(Collection<DNSChaos> items);
    public A removeFromItems(DNSChaos... items);
    public A removeAllFromItems(Collection<DNSChaos> items);
    public A removeMatchingFromItems(Predicate<DNSChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<DNSChaos> getItems();
    public List<DNSChaos> buildItems();
    public DNSChaos buildItem(int index);
    public DNSChaos buildFirstItem();
    public DNSChaos buildLastItem();
    public DNSChaos buildMatchingItem(Predicate<DNSChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<DNSChaosBuilder> predicate);
    public A withItems(List<DNSChaos> items);
    public A withItems(DNSChaos... items);
    public Boolean hasItems();
    public DNSChaosListFluent.ItemsNested<A> addNewItem();
    public DNSChaosListFluent.ItemsNested<A> addNewItemLike(DNSChaos item);
    public DNSChaosListFluent.ItemsNested<A> setNewItemLike(int index,DNSChaos item);
    public DNSChaosListFluent.ItemsNested<A> editItem(int index);
    public DNSChaosListFluent.ItemsNested<A> editFirstItem();
    public DNSChaosListFluent.ItemsNested<A> editLastItem();
    public DNSChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSChaosFluent<DNSChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/DNSChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface DNSChaosListFluent<A extends DNSChaosListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,DNSChaos item);
    public A setToItems(int index,DNSChaos item);
    public A addToItems(DNSChaos... items);
    public A addAllToItems(Collection<DNSChaos> items);
    public A removeFromItems(DNSChaos... items);
    public A removeAllFromItems(Collection<DNSChaos> items);
    public A removeMatchingFromItems(Predicate<DNSChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<DNSChaos> getItems();
    public List<DNSChaos> buildItems();
    public DNSChaos buildItem(int index);
    public DNSChaos buildFirstItem();
    public DNSChaos buildLastItem();
    public DNSChaos buildMatchingItem(Predicate<DNSChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<DNSChaosBuilder> predicate);
    public A withItems(List<DNSChaos> items);
    public A withItems(DNSChaos... items);
    public Boolean hasItems();
    public DNSChaosListFluent.ItemsNested<A> addNewItem();
    public DNSChaosListFluent.ItemsNested<A> addNewItemLike(DNSChaos item);
    public DNSChaosListFluent.ItemsNested<A> setNewItemLike(int index,DNSChaos item);
    public DNSChaosListFluent.ItemsNested<A> editItem(int index);
    public DNSChaosListFluent.ItemsNested<A> editFirstItem();
    public DNSChaosListFluent.ItemsNested<A> editLastItem();
    public DNSChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSChaosFluent<DNSChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
